@@ -8,6 +8,7 @@ class Handler(object):
   EXPOSED_TRANSFORMERS = {
     "answer": t2t.Answerer,
     "count": t2t.Counter,
+    "fit": t2t.Fitter,
     "measure": t2t.Measurer,
     "question": t2t.Questioner,
     "search": t2t.Searcher,
@@ -19,9 +20,14 @@ class Handler(object):
     "vectorize": t2t.Vectorizer,
   }
 
+  transformer_instances = {}
+
   def _transformer_handler(self, transformation, **kwargs):
-    transformer = self.__class__.transformer_instances.get(transformation, self.__class__.EXPOSED_TRANSFORMERS[transformation]())
-    self.__class__.transformer_instances[transformation] = transformer
+    if transformation in self.__class__.transformer_instances:
+      transformer = self.__class__.transformer_instances[transformation]
+    else:
+      transformer = self.__class__.EXPOSED_TRANSFORMERS[transformation]()
+      self.__class__.transformer_instances[transformation] = transformer
     return transformer.transform(input_lines=self.input_lines, src_lang=self.src_lang, **kwargs)
     
   def __init__(self, input_lines=[], src_lang='en', **kwargs):
@@ -31,4 +37,3 @@ class Handler(object):
       handler = lambda x: lambda **kwargs: self._transformer_handler(transformation=x, **kwargs)
       handler = handler(k)
       setattr(self, k, handler)
-    self.__class__.transformer_instances = {}
\ No newline at end of file
